# Transmission RSS Manager - Development Guide

## Commands
- Install dependencies: `npm install` (needed for rss-feed-manager.js)
- Setup: `./main-installer.sh` (main installation script)
- Run application: `node modules/rss-feed-manager.js`

## Code Style Guidelines

### JavaScript
- Indentation: 2 spaces
- Naming: camelCase for variables/functions, PascalCase for classes
- Semicolons: required
- Imports: group standard libraries first, then custom modules
- Error handling: use try/catch with descriptive error messages
- Functions: prefer arrow functions for callbacks
- String formatting: use template literals (`${variable}`)

### Bash Scripts
- Indentation: 2 spaces
- Function definition: use `function name() {}`
- Comments: add descriptive comments before functions
- Error handling: check return codes and provide meaningful feedback
- Organization: follow modular approach (each script handles specific tasks)

### HTML/CSS
- Indentation: 4 spaces
- CSS: use variables for consistent styling
- Layout: ensure mobile-responsive design
- HTML: use semantic elements when appropriate

## TODO List

### Next Steps
- [ ] Test system with actual RSS feeds and torrents
- [ ] Implement automated testing for key components
- [ ] Add advanced content detection features
- [ ] Enhance UI with visual download statistics
- [ ] Add more notification options (email, messaging platforms)

### Improvements
- [ ] Add user preference settings for automatic downloads
- [ ] Implement batch operations for torrent management
- [ ] Create detailed logging system with rotation
- [ ] Add support for multiple transmission instances
- [ ] Improve error recovery mechanisms
- [ ] Create a mobile-friendly responsive design
- [ ] Add dark mode support
- [ ] Implement content filtering based on regex patterns
- [ ] Add scheduling options for RSS checks
- [ ] Create dashboard with download metrics